/*
    Copyright (C) 2022 Tenable, Inc.

	Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

		http://www.apache.org/licenses/LICENSE-2.0

	Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/

package httpserver

import "fmt"

func (g *APIServer) validateFiles(privateKeyFile, certFile string) error {
	keylength := len(privateKeyFile)
	certlength := len(certFile)

	if keylength > 0 && certlength == 0 {
		return fmt.Errorf("private key file provided but certificate file missing")
	} else if keylength == 0 && certlength > 0 {
		return fmt.Errorf("certificate file provided but private key file missing")
	}

	return nil
}
